@@ -15,6 +15,7 @@ crsr_ptn_t	*get_crsr_ptn( void );
 crsr_ptn_t	*get_sub_crsr_ptn( void );
 bool_t	set_crsr_ptn( crsr_ptn_t *dst, crsr_ptn_t *src );
 void	up_dun( long d );
+void	reset_all_save( bool_t flg_appear );
 void	reset_all( bool_t flg_appear );
 void	make_dun( void );
 void	make_fence( void );
@@ -93,6 +94,9 @@ door_t	*get_door_near( long x, long y, act_kind_t act_kind );
 door_t	*get_door_disperse( mbr_t *mbr, act_kind_t act_kind );
 door_t	*get_door_randm( long x, long y, act_kind_t act_kind );
 door_t	*get_door_towner( long x, long y, long r );
+void	set_door_pos_chk_find(
+	door_t *p, long x, long y, pos_t *pos, long *dx, long *dy
+);
 bool_t	chk_mark_door( door_t *p, act_kind_t act_kind );
 bool_t	up_stairs( void );
 bool_t	down_stairs( void );
