@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: dun.c,v 1.101 2007/03/17 23:38:58 bowkenken Exp $
+* $Id: dun.c,v 1.102 2007/05/12 09:20:47 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -372,6 +372,18 @@ void	up_dun( long d )
 	reset_all( TRUE );
 }
 
+/***************************************************************
+* µܤ(μ)
+* bool_t flg_appear : ѡƥνи򤹤뤫?
+***************************************************************/
+
+void	reset_all_save( bool_t flg_appear )
+{
+	srandm( g_randm_seed_save );
+
+	reset_all( flg_appear );
+}
+
 /***************************************************************
 * µܤ
 * bool_t flg_appear : ѡƥνи򤹤뤫?
