@@ -62,7 +62,11 @@ bool_t	load_game_conf_menu_line(
 void	back_up_game_conf( void );
 bool_t	save_game_conf( void );
 bool_t	save_game_conf_ver_1( const ver_t *ver );
+bool_t	save_game_conf_contents( FILE *fp, const ver_t *ver );
+bool_t	save_game_conf_language( FILE *fp, const ver_t *ver );
+bool_t	save_game_conf_frame_rate( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_scroll( FILE *fp, const ver_t *ver );
+bool_t	save_game_conf_flg( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_vfx( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_color( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_color_sub(
@@ -289,6 +293,21 @@ bool_t	load_game_data_pet_formation_ver_1(
 bool_t	load_game_data_request_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt
 );
+bool_t	load_game_replay( bool_t flg_txt_data, long n );
+void	reset_load_game_replay( long n );
+bool_t	load_game_replay_head_ver_1( FILE *fp, ver_t *ver, bool_t flg_txt );
+bool_t	load_game_replay_ver_1( FILE *fp, const ver_t *ver, bool_t flg_txt );
+bool_t	load_game_replay_parse_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt
+);
+bool_t	load_game_replay_id_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt,
+	char *id
+);
+bool_t	load_game_replay_str_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt,
+	char *str
+);
 bool_t	load_game_data_n( FILE *fp, long *n );
 bool_t	load_game_data_s( FILE *fp, char *s, long len );
 bool_t	load_game_data_c( FILE *fp, char *c );
@@ -297,7 +316,12 @@ bool_t	load_game_data_skip_token( FILE *fp, rc_token_t c, bool_t flg_draw );
 bool_t	save_game_data( bool_t flg_txt, long n );
 bool_t	save_game_data_sub( bool_t flg_txt, long n );
 bool_t	save_game_data_ver_1( const ver_t *ver, bool_t flg_txt, long n );
-bool_t	save_game_data_cnf_ver_1( const ver_t *ver, long n );
+bool_t	save_game_data_contents(
+	FILE *fp, const ver_t *ver, bool_t flg_txt
+);
+bool_t	save_game_data_randm_seed_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt
+);
 bool_t	save_game_data_dun_lev_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt
 );
@@ -461,10 +485,28 @@ bool_t	save_game_data_pet_formation_ver_1(
 bool_t	save_game_data_request_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt
 );
+bool_t	save_game_data_cnf_ver_1( const ver_t *ver, long n );
+bool_t	save_game_data_cnf_contents(
+	FILE *fp, const ver_t *ver
+);
+bool_t	save_game_replay( void );
+bool_t	save_game_replay_slot( long n );
+bool_t	save_game_replay_ver_1( const ver_t *ver, long n );
+bool_t	save_game_replay_contents(
+	FILE *fp, const ver_t *ver, long n
+);
 FILE	*open_game_data( char type, long n, bool_t flg_txt );
 FILE	*open_game_data_cnf( char type, long n );
-bool_t	get_save_load_ttl( char *msg, long n, bool_t flg_txt );
-bool_t	get_game_data_head_time( char *str, long n, bool_t flg_txt );
+FILE	*open_game_replay( char type, long n );
+void	remove_replay_file( long n );
+bool_t	get_save_load_ttl(
+	char *msg, long n,
+	bool_t flg_txt, bool_t flg_replay
+);
+bool_t	get_game_data_head_time(
+	char *str, long n,
+	bool_t flg_txt, bool_t flg_replay
+);
 long	load_char( FILE *fp, bool_t flg_chk_eof );
 char	*load_line_skip_spc( FILE *fp, bool_t flg_chk_eof );
 char	*load_line( FILE *fp, bool_t flg_chk_eof );
@@ -573,8 +615,9 @@ bool_t	chk_exist_file( char *s );
 bool_t	chk_exist_dir( char *s );
 bool_t	make_dir( char *path );
 bool_t	make_dir_node( char *path );
-char	*cv_esc_c( const long c );
-char	*cv_esc_str( const char *str );
+char	*cv_esc_quote_c( const long c );
+char	*cv_esc_quote_str( const char *str );
+char	*cv_esc_ctrl_str( const char *str );
 long	srandm_crypt( long n );
 long	randm_crypt( long c );
 void	reset_load_save( char *path, bool_t flg_txt );
