@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.c,v 1.82 2007/03/17 21:57:07 bowkenken Exp $
+* $Id: gmain.c,v 1.90 2007/05/05 21:16:08 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -73,7 +73,7 @@ struct termio	pre_tbuf;
 ***************************************************************/
 
 #define	OPT_ARG_MAX_LEN	128
-#define	STR_OPT	"GCUD:S:k:e:s:p:md:Vh"
+#define	STR_OPT	"GCUD:S:l:k:e:s:p:md:Vh"
 
 #if	HAVE_GETOPT_LONG
 static struct option	long_opt[] = {
@@ -82,6 +82,7 @@ static struct option	long_opt[] = {
 	{ "gui-and-cui",   no_argument,       NULL, 'U' },
 	{ "sel-graph-dir", required_argument, NULL, 'D' },
 	{ "map-scale",     required_argument, NULL, 'S' },
+	{ "language",      required_argument, NULL, 'l' },
 	{ "clear-key-buf", required_argument, NULL, 'k' },
 	{ "echo-key",      required_argument, NULL, 'e' },
 	{ "use-curses",    required_argument, NULL, 's' },
@@ -104,10 +105,12 @@ char	str_usage[] = {
 	"  -G, --gui                set GUI mode\n"
 	"  -C, --cui                set CUI mode\n"
 	"  -U, --gui-and-cui        set GUI and CUI mode\n"
-	"  -D, --sel-graph-dir=DIR  select graphic directory\n"
+	"  -D, --sel-graph-dir=DIR  select graphic directory:\n"
 	"                             graphic directory\n"
-	"  -S, --map-scale          set scale of map character\n"
+	"  -S, --map-scale          set scale of map character:\n"
 	"                             scale(%%)\n"
+	"  -l, --language=LANGUAGE  set language:\n"
+	"                             language\n"
 	"  -k, --clear-key-buf=FLAG clear key buffer:\n"
 	"                             ON, OFF\n"
 	"  -e, --echo-key=FLAG      echo key:\n"
@@ -144,10 +147,12 @@ void	init_arg( void )
 	g_graph_scale_rate = _100_PERCENT;
 	g_gui_key_kind = GUI_KEY_KIND_CONSOLE;
 
+	g_language = NULL;
+
 	g_flg_clr_key_buf_arg_overwrite = FALSE;
 	g_flg_clr_key_buf_arg = FALSE;
-	g_flg_clr_key_buf = FALSE;
-	g_flg_clr_key_buf_menu = FALSE;
+	g_flg_clr_key_buf = TRUE;
+	g_flg_clr_key_buf_menu = TRUE;
 
 	g_flg_echo_key = FALSE;
 
@@ -165,6 +170,8 @@ void	init_arg( void )
 
 void	chk_arg( int argc, char **argv )
 {
+	long	len;
+	long	mem_size;
 #if	(!HAVE_GETOPT && !HAVE_GETOPT_LONG)
 	long	n = 0;
 	char	*optarg;
@@ -217,6 +224,16 @@ void	chk_arg( int argc, char **argv )
 		case 'S':
 			g_graph_scale_rate = strtol( optarg, NULL, 0 );
 			break;
+		case 'l':
+			if( g_language != NULL )
+				free_mem( g_language );
+
+			len = str_len_std( optarg );
+			mem_size = len * sizeof( char );
+			g_language = (char *)alloc_mem( mem_size, TRUE );
+
+			str_nz_cpy( g_language, optarg, len );
+			break;
 		case 'k':
 			g_flg_clr_key_buf_arg_overwrite = TRUE;
 			g_flg_clr_key_buf_arg = chk_opt_flg( optarg );
@@ -356,6 +373,7 @@ void	init_game( void )
 
 	init_msg();
 	init_draw();
+	init_replay();
 
 	init_game_file();
 
@@ -375,8 +393,8 @@ void	init_game( void )
 	init_item();
 	init_trap();
 	init_fx();
-	init_chr();
 	init_spell();
+	init_chr();
 	init_town();
 	init_menu();
 	init_tmenu();
@@ -386,6 +404,11 @@ void	init_game( void )
 	init_request();
 
 	init_mbr_formation();
+
+	if( g_flg_debug )
+		init_spell_debug();
+	else
+		init_spell_dflt();
 	init_spell_nin();
 
 	if( g_flg_debug )
@@ -408,18 +431,12 @@ void	init_game( void )
 void	game_main( void )
 {
 	if( !g_flg_debug ){
-		door_t	*dr;
-
 		print_msg( FLG_NULL, MSG_HINT_CANCEL_MENU_1 );
 		print_msg( FLG_NULL, MSG_HINT_CANCEL_MENU_2 );
 
 		menu_bar_load();
 
-		dr = get_shop_door( SHOP_N_BAR );
-		if( dr != NULL ){
-			open_door_shop( dr->n );
-			exec_all_phase();
-		}
+		party_exit_bar();
 	}
 
 	while( 1 ){
@@ -446,18 +463,20 @@ void	exit_game( long code )
 
 void	close_game( long code )
 {
-	FILE	*fp;
-
 	curs_move( WIN_MSG_DRAW_MIN_Y, SCREEN_MIN_X );
 
 	reset_scrn();
 
-	if( code == 0 )
-		fp = stdout;
-	else
-		fp = stderr;
+	fflush( stdout );
+	fflush( stderr );
 
-	version( fp );
+	if( code == 0 )
+		version( stdout );
+	else
+		version( stderr );
+
+	fflush( stdout );
+	fflush( stderr );
 }
 
 /***************************************************************
