@@ -156,6 +156,10 @@ void	set_edit_user_menu( menu_t *ls, menu_call_back_t func, char *ttl );
 char	*cb_menu_user_arrange_top_sel( menu_t **pp, menu_t **dflt );
 char	*cb_menu_user_arrange_bottom_sel( menu_t **pp, menu_t **dflt );
 char	*cb_menu_user_remove_sel( menu_t **pp, menu_t **dflt );
+char	*cb_menu_replay_load( menu_t **pp, menu_t **dflt );
+char	*cb_menu_replay_save( menu_t **pp, menu_t **dflt );
+long	menu_replay_sel_load( void );
+char	*cb_menu_replay_sel_load( menu_t **pp, menu_t **dflt );
 char	*cb_menu_system( menu_t **pp, menu_t **dflt );
 char	*cb_menu_wizard( menu_t **pp, menu_t **dflt );
 char	*cb_menu_wizard_on_light( menu_t **pp, menu_t **dflt );
