@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: imenu.c,v 1.23 2007/03/11 20:49:58 bowkenken Exp $
+* $Id: imenu.c,v 1.27 2007/05/12 09:20:47 bowkenken Exp $
 ***************************************************************/
 
 #define	IMENU_C
@@ -54,6 +54,9 @@ static long	g_user_menu_n;
 static char	g_user_menu_name[USER_MENU_MAX_N][MENU_MSG_MAX_LEN + 1];
 static char	g_user_menu_cmd[USER_MENU_MAX_N][MACRO_MAX_LEN + 1];
 
+static long	g_replay_sel_load_n;
+static menu_t	ls_menu_replay_sel_load[MENU_SAVE_LOAD_MAX_N * 2];
+
 /**/
 
 #include	"imenu-tab.h"
@@ -4098,6 +4101,152 @@ char	*cb_menu_user_remove_sel( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_replay_load( menu_t **pp, menu_t **dflt )
+{
+	long	n;
+
+	n = menu_replay_sel_load();
+
+	if( n == SAVE_N_SEL )
+		return STR_MENU_CANCEL;
+
+	if( load_game_replay( FALSE, n ) ){
+		reset_all_save( TRUE );
+		party_exit_bar();
+
+		return "/";
+	}
+
+	return STR_MENU_CANCEL;
+}
+
+/**/
+
+char	*cb_menu_replay_save( menu_t **pp, menu_t **dflt )
+{
+	if( save_game_replay() )
+		return NULL;
+	else
+		return STR_MENU_CANCEL;
+}
+
+/**/
+
+long	menu_replay_sel_load( void )
+{
+	menu_t	*ls;
+	menu_t	*dflt;
+	char	key;
+	long	k;
+	char	*ret;
+	long	i;
+
+	ls = ls_menu_replay_sel_load;
+	dflt = NULL;
+	k = 0;
+	key = 'A';
+
+	str_nz_cpy( ls[k].path, "/replay load list", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
+	ls[k].n_msg = N_MSG_NULL;
+	ls[k].msg[0] = '\0';
+	ls[k].call_back = NULL;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
+	for( i = 0; i < MENU_SAVE_LOAD_MAX_N; i++ ){
+		bool_t	flg_exist_data;
+
+		if( (i != 0) && (i % MENU_SAVE_LOAD_N_PER_PAGE == 0) ){
+			key = 'A';
+
+			str_nz_cpy( ls[k].path,
+					"/replay load list/page separator",
+					MENU_PATH_MAX_LEN );
+			str_nz_cpy( ls[k].kind, "<PageSeparator>",
+					MENU_KIND_MAX_LEN );
+			ls[k].accel_key = '\0';
+			ls[k].short_key[0] = '\0';
+			ls[k].n_msg = N_MSG_NULL;
+			ls[k].msg[0] = '\0';
+			ls[k].call_back = NULL;
+			ls[k].arg = NULL;
+			ls[k].flg = FLG_NULL;
+			k++;
+		}
+
+		if( i % MENU_SAVE_LOAD_N_PER_PAGE == 0 ){
+			str_nz_cpy( ls[k].path,
+					"/replay load list/title",
+					MENU_PATH_MAX_LEN );
+			str_nz_cpy( ls[k].kind, "<Title>",
+					MENU_KIND_MAX_LEN );
+			ls[k].accel_key = '\0';
+			ls[k].short_key[0] = '\0';
+			ls[k].n_msg = N_MSG_NULL;
+			str_nz_cpy( ls[k].msg, MSG_MENU_REPLAY_LOAD,
+					MENU_MSG_MAX_LEN );
+			ls[k].call_back = NULL;
+			ls[k].arg = NULL;
+			ls[k].flg = FLG_NULL;
+			k++;
+		}
+
+		sprintf( ls[k].path, "/replay load list/%ld", i );
+		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		ls[k].accel_key = key;
+		ls[k].short_key[0] = '\0';
+		ls[k].n_msg = N_MSG_NULL;
+		flg_exist_data = get_save_load_ttl( ls[k].msg, i,
+				FALSE, TRUE );
+		ls[k].call_back = cb_menu_replay_sel_load;
+		if( flg_exist_data )
+			ls[k].arg = (void *)i;
+		else
+			ls[k].arg = (void *)-1;
+		ls[k].flg = FLG_NULL;
+		k++;
+
+		key++;
+	}
+	ls[k].path[0] = '\0';
+
+	g_replay_sel_load_n = -1;
+
+	while( 1 ){
+		ret = exec_menu( ls, dflt, NULL );
+
+		if( ret == NULL ){
+			if( g_replay_sel_load_n <= -1 )
+				continue;
+			else
+				return g_replay_sel_load_n;
+		}
+
+		return SAVE_N_SEL;
+	}
+
+	return SAVE_N_SEL;
+}
+
+/**/
+
+char	*cb_menu_replay_sel_load( menu_t **pp, menu_t **dflt )
+{
+	if( pp == NULL ){
+		g_replay_sel_load_n = -1;
+		return STR_MENU_ERR;
+	}
+
+	g_replay_sel_load_n = (long)((*pp)->arg);
+	return NULL;
+}
+
+/**/
+
 char	*cb_menu_system( menu_t **pp, menu_t **dflt )
 {
 	set_menu_dflt_misc( *pp );
