@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: inc.h,v 1.36 2007/03/17 21:57:07 bowkenken Exp $
+* $Id: inc.h,v 1.39 2007/03/31 21:16:03 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	INC_H
@@ -51,6 +51,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 #include	"curs.h"
 #include	"menu.h"
@@ -73,6 +74,7 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
@@ -104,6 +106,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 #include	"trap.h"
+/*#include	"replay.h"*/
 #include	"draw.h"
 #include	"curs.h"
 #include	"menu.h"
@@ -126,6 +129,7 @@
 #include	"fight-prot.h"
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 /*#include	"menu-prot.h"*/
@@ -159,6 +163,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 #include	"curs.h"
 /*#include	"menu.h"*/
@@ -181,6 +186,7 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 /*#include	"menu-prot.h"*/
@@ -210,6 +216,61 @@
 
 /***************************************************************/
 
+#ifdef	REPLAY_C
+
+#include	"gmain.h"
+#include	"misc.h"
+#include	"turn.h"
+/*#include	"dun.h"*/
+#include	"town.h"
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+/*#include	"chr.h"*/
+/*#include	"party.h"*/
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+#include	"replay.h"
+#include	"draw.h"
+/*#include	"curs.h"*/
+/*#include	"menu.h"*/
+#include	"amenu.h"
+/*#include	"request.h"*/
+#include	"gfile.h"
+#include	"msg.h"
+/*#include	"ver.h"*/
+#include	"gmain-prot.h"
+#include	"misc-prot.h"
+#include	"turn-prot.h"
+/*#include	"dun-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+#include	"replay-prot.h"
+#include	"draw-prot.h"
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+#include	"gfile-prot.h"
+#include	"msg-prot.h"
+
+#endif	/* REPLAY_C */
+
+/***************************************************************/
+
 #ifdef	DRAW_C
 
 #include	"gmain.h"
@@ -226,6 +287,7 @@
 /*#include	"fight.h"*/
 #include	"fx.h"
 /*#include	"trap.h"*/
+#include	"replay.h"
 #include	"draw.h"
 /*#include	"curs.h"*/
 /*#include	"menu.h"*/
@@ -248,6 +310,7 @@
 #include	"fight-prot.h"
 #include	"fx-prot.h"
 /*#include	"trap-prot.h"*/
+#include	"replay-prot.h"
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
@@ -291,6 +354,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 #include	"menu.h"
@@ -313,6 +377,7 @@
 /*#include	"fight-prot.h"*/
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
@@ -349,6 +414,7 @@
 #include	"fight.h"
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 /*#include	"menu.h"*/
@@ -371,6 +437,7 @@
 #include	"fight-prot.h"
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 /*#include	"menu-prot.h"*/
@@ -402,6 +469,7 @@
 /*#include	"fight.h"*/
 #include	"fx.h"
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 /*#include	"menu.h"*/
@@ -424,6 +492,7 @@
 #include	"fight-prot.h"
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
@@ -455,6 +524,7 @@
 /*#include	"fight.h"*/
 #include	"fx.h"
 #include	"trap.h"
+#include	"replay.h"
 #include	"draw.h"
 #include	"curs.h"
 #include	"menu.h"
@@ -477,6 +547,7 @@
 /*#include	"fight-prot.h"*/
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+#include	"replay-prot.h"
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
@@ -507,6 +578,7 @@
 #include	"fight.h"
 #include	"fx.h"
 #include	"trap.h"
+#include	"replay.h"
 #include	"draw.h"
 #include	"curs.h"
 #include	"menu.h"
@@ -529,6 +601,7 @@
 #include	"fight-prot.h"
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+#include	"replay-prot.h"
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
@@ -576,6 +649,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 #include	"trap.h"
+/*#include	"replay.h"*/
 #include	"draw.h"
 #include	"curs.h"
 #include	"menu.h"
@@ -598,6 +672,7 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 #include	"trap-prot.h"
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
@@ -631,6 +706,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 #include	"curs.h"
 /*#include	"menu.h"*/
@@ -653,6 +729,7 @@
 /*#include	"fight-prot.h"*/
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 /*#include	"menu-prot.h"*/
@@ -685,6 +762,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 #include	"curs.h"
 /*#include	"menu.h"*/
@@ -707,6 +785,7 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 /*#include	"menu-prot.h"*/
@@ -741,6 +820,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 /*#include	"menu.h"*/
@@ -763,6 +843,7 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
@@ -797,6 +878,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 #include	"menu.h"
@@ -819,6 +901,7 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 #include	"menu-prot.h"
@@ -852,6 +935,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 /*#include	"menu.h"*/
@@ -874,6 +958,7 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
@@ -905,6 +990,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 #include	"menu.h"
@@ -927,6 +1013,7 @@
 /*#include	"fight-prot.h"*/
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
@@ -960,6 +1047,7 @@
 /*#include	"fight.h"*/
 #include	"fx.h"
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 /*#include	"menu.h"*/
@@ -983,6 +1071,7 @@
 /*#include	"fight-prot.h"*/
 #include	"fx-prot.h"
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
@@ -1014,6 +1103,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 #include	"trap.h"
+/*#include	"replay.h"*/
 #include	"draw.h"
 #include	"curs.h"
 /*#include	"menu.h"*/
@@ -1036,6 +1126,7 @@
 #include	"fight-prot.h"
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 /*#include	"menu-prot.h"*/
@@ -1067,6 +1158,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 /*#include	"menu.h"*/
@@ -1089,6 +1181,7 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
@@ -1120,6 +1213,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 #include	"menu.h"
@@ -1142,6 +1236,7 @@
 #include	"fight-prot.h"
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
@@ -1173,6 +1268,7 @@
 /*#include	"fight.h"*/
 #include	"fx.h"
 #include	"trap.h"
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 /*#include	"menu.h"*/
@@ -1196,6 +1292,7 @@
 /*#include	"fight-prot.h"*/
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
@@ -1227,6 +1324,7 @@
 /*#include	"fight.h"*/
 #include	"fx.h"
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 #include	"curs.h"
 #include	"menu.h"
@@ -1249,6 +1347,7 @@
 /*#include	"fight-prot.h"*/
 #include	"fx-prot.h"
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
@@ -1280,6 +1379,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 #include	"curs.h"
 #include	"menu.h"
@@ -1302,6 +1402,7 @@
 /*#include	"fight-prot.h"*/
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
@@ -1333,6 +1434,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 #include	"curs.h"
 #include	"menu.h"
@@ -1355,6 +1457,7 @@
 /*#include	"fight-prot.h"*/
 #include	"fx-prot.h"
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
@@ -1386,6 +1489,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 #include	"menu.h"
@@ -1408,6 +1512,7 @@
 /*#include	"fight-prot.h"*/
 #include	"fx-prot.h"
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 #include	"menu-prot.h"
@@ -1439,6 +1544,7 @@
 #include	"fight.h"
 #include	"fx.h"
 #include	"trap.h"
+/*#include	"replay.h"*/
 #include	"draw.h"
 #include	"curs.h"
 #include	"menu.h"
@@ -1461,6 +1567,7 @@
 #include	"fight-prot.h"
 #include	"fx-prot.h"
 #include	"trap-prot.h"
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
@@ -1492,6 +1599,7 @@
 /*#include	"fight.h"*/
 #include	"fx.h"
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 #include	"menu.h"
@@ -1514,6 +1622,7 @@
 /*#include	"fight-prot.h"*/
 #include	"fx-prot.h"
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
@@ -1547,6 +1656,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 /*#include	"menu.h"*/
@@ -1569,6 +1679,7 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
@@ -1603,6 +1714,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 /*#include	"menu.h"*/
@@ -1625,6 +1737,7 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
@@ -1659,6 +1772,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 #include	"menu.h"
@@ -1681,6 +1795,7 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
@@ -1766,6 +1881,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 #include	"curs.h"
 /*#include	"menu.h"*/
@@ -1788,6 +1904,7 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 /*#include	"menu-prot.h"*/
@@ -1827,6 +1944,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 /*#include	"menu.h"*/
@@ -1849,6 +1967,7 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
@@ -1888,6 +2007,7 @@
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
+/*#include	"replay.h"*/
 #include	"draw.h"
 /*#include	"curs.h"*/
 /*#include	"menu.h"*/
@@ -1910,6 +2030,7 @@
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
