@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-dos.c,v 1.12 2007/02/04 18:50:59 bowkenken Exp $
+* $Id: main-dos.c,v 1.13 2007/03/02 05:19:47 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -42,9 +42,10 @@
 * return : λ
 ***************************************************************/
 
-int	main_dos( void )
+int	main_dos( int argc, char **argv )
 {
 	init_arg();
+	chk_arg( argc, argv );
 
 	init_game();
 	game_main();
