@@ -6,7 +6,7 @@ extern "C" {
 
 void	init_var_menu( void );
 void	init_menu( void );
-void	init_ls_menu_macro( void );
+void	init_ls_menu_func( void );
 char	*exec_menu( menu_t *p, menu_t *dflt, char *str_goto );
 bool_t	chk_err_menu_kind( menu_t *ls );
 bool_t	set_menu_check_item( menu_t *p );
@@ -15,7 +15,7 @@ ask_t	exec_menu_ask( char *ttl, ask_t dflt, bool_t can_cancel );
 char	*cb_menu_ask_init( menu_t **pp, menu_t **dflt );
 char	*cb_menu_ask_yes( menu_t **pp, menu_t **dflt );
 char	*cb_menu_ask_no( menu_t **pp, menu_t **dflt );
-char	*exec_menu_sel_num( long min, long max, long *p );
+char	*exec_menu_sel_num( long *p, long min, long max );
 void	sel_menu_clr( draw_menu_t *data );
 menu_t	*sel_menu( menu_t *p, menu_t *dflt );
 long	set_ls_menu(
@@ -43,8 +43,8 @@ void	chk_dup_short_key_init( void );
 bool_t	chk_dup_short_key_main( menu_t *ls );
 bool_t	chk_dup_short_key_sub( unsigned char c, menu_t *ls );
 bool_t	chk_short_key( menu_t *ls, long c );
-menu_t	*get_ls_menu_macro( void );
-char	*get_macro( long n );
+menu_t	*get_ls_menu_func( void );
+char	*get_func( long n );
 bool_t	get_flg_chk_short_key( void );
 bool_t	get_flg_space_select( void );
 bool_t	set_flg_space_select( bool_t flg );
