@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: misc.c,v 1.37 2006/09/07 00:30:28 bowkenken Exp $
+* $Id: misc.c,v 1.39 2007/03/31 21:16:03 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -39,7 +39,7 @@
 
 /* μ */
 
-static long	rand_seed = 1;
+static long	randm_seed = 1;
 
 /***************************************************************
 * ߤ򥳥ޡեޥåʸѴ
@@ -152,7 +152,17 @@ long	max_l( long n1, long n2 )
 
 void	srandm( long n )
 {
-	rand_seed = n;
+	randm_seed = n;
+}
+
+/***************************************************************
+* μ֤
+* long n : 
+***************************************************************/
+
+long	get_randm_seed( void )
+{
+	return randm_seed;
 }
 
 /***************************************************************
@@ -182,16 +192,16 @@ long	randm_sub( long n )
 {
 	long	a;
 
-	rand_seed += 15349;
-	rand_seed *= 3793;
-	rand_seed += 598393;
-	a = (rand_seed & 0xffff0000) >> 16;
-	rand_seed = ((rand_seed & 0x0000ffff) << 16) + a;
-	rand_seed += 379;
-	rand_seed = labs( rand_seed );
+	randm_seed += 15349;
+	randm_seed *= 3793;
+	randm_seed += 598393;
+	a = (randm_seed & 0xffff0000) >> 16;
+	randm_seed = ((randm_seed & 0x0000ffff) << 16) + a;
+	randm_seed += 379;
+	randm_seed = labs( randm_seed );
 
 	if( n > 0 )
-		return( rand_seed % n );
+		return( randm_seed % n );
 	else
 		return 0;
 }
