@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu-tab.h,v 1.15 2007/01/11 17:31:35 bowkenken Exp $
+* $Id: mmenu-tab.h,v 1.18 2007/03/31 21:16:03 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MMENU_TAB_H
@@ -1014,6 +1014,35 @@ menu_t	ls_menu_main[] = {
 		cb_menu_system, NULL,
 		FLG_NULL,
 	},
+/* replay begin */
+	{
+		"/misc/system/replay",
+		"<Branch>",
+		'R',
+		"",
+		N_MSG_MENU_REPLAY, "",
+		NULL, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/system/replay/load",
+		"<Branch>",
+		'L',
+		"",
+		N_MSG_MENU_REPLAY_LOAD, "",
+		cb_menu_replay_load, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/system/replay/save",
+		"<Item>",
+		'S',
+		"p",
+		N_MSG_MENU_REPLAY_SAVE, "",
+		cb_menu_replay_save, NULL,
+		FLG_NULL,
+	},
+/* replay end */
 /* wizard begin */
 	{
 		"/misc/system/wizard",
