@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu.c,v 1.18 2007/03/17 21:57:07 bowkenken Exp $
+* $Id: mmenu.c,v 1.24 2007/05/12 09:20:47 bowkenken Exp $
 ***************************************************************/
 
 #define	MMENU_C
@@ -462,9 +462,8 @@ char	*cb_menu_exec( menu_t **pp, menu_t **dflt )
 {
 	set_menu_dflt_main( *pp );
 
-	exec_all_phase();
-
 	inc_turn();
+	exec_all_phase();
 
 	return NULL;
 }
@@ -1083,9 +1082,6 @@ bool_t	menu_mark_square_pos( pos_t pos )
 	sq->pre_x = sq->x;
 	sq->pre_y = sq->y;
 
-	sq->dir_x = 0;
-	sq->dir_y = 0;
-
 	flg_loop = TRUE;
 	while( flg_loop ){
 		switch( get_key( g_flg_clr_key_buf ) ){
@@ -1096,22 +1092,22 @@ bool_t	menu_mark_square_pos( pos_t pos )
 		case CASE_ENTER:
 		case CASE_CRSR_UP:
 		case '-':
-			sq->dir_y = -1;
+			sq->dir = SQUARE_DIR_NORTH;
 			flg_loop = FALSE;
 			break;
 		case CASE_CRSR_DOWN:
 		case '+':
-			sq->dir_y = +1;
+			sq->dir = SQUARE_DIR_SOUTH;
 			flg_loop = FALSE;
 			break;
 		case CASE_CRSR_LEFT:
 		case '/':
-			sq->dir_x = -1;
+			sq->dir = SQUARE_DIR_WEST;
 			flg_loop = FALSE;
 			break;
 		case CASE_CRSR_RIGHT:
 		case '*':
-			sq->dir_x = +1;
+			sq->dir = SQUARE_DIR_EAST;
 			flg_loop = FALSE;
 			break;
 		}
@@ -2295,6 +2291,7 @@ char	*cb_menu_goto_item( menu_t **pp, menu_t **dflt )
 char	*cb_menu_move( menu_t **pp, menu_t **dflt )
 {
 	square_t	*sq;
+	square_dir_t	pre_dir;
 
 	set_menu_dflt_main( *pp );
 
@@ -2303,24 +2300,47 @@ char	*cb_menu_move( menu_t **pp, menu_t **dflt )
 	sq->pre_x = sq->x;
 	sq->pre_y = sq->y;
 
-	sq->dir_x = 0;
-	sq->dir_y = 0;
+	pre_dir = sq->dir;
+	sq->dir = SQUARE_DIR_MAX_N;
+
+	/* ưθ˹碌ƤΥ󥫡θꤹ */
+
 	if( labs( sq->x - g_crsr.x ) > labs( sq->y - g_crsr.y ) ){
 		if( g_crsr.x < sq->x ){
-			sq->dir_x = -1;
+			sq->dir = SQUARE_DIR_WEST;
 		} else if( g_crsr.x > sq->x ){
-			sq->dir_x = +1;
+			sq->dir = SQUARE_DIR_EAST;
 		}
 	} else {
 		if( g_crsr.y < sq->y ){
-			sq->dir_y = -1;
+			sq->dir = SQUARE_DIR_NORTH;
 		} else if( g_crsr.y > sq->y ){
-			sq->dir_y = +1;
+			sq->dir = SQUARE_DIR_SOUTH;
 		}
 	}
-	if( (sq->dir_x == 0) && (sq->dir_y == 0) ){
-		sq->dir_x = 0;
-		sq->dir_y = -1;
+
+	/* Ʊɸǥ󥫡ꤷ 90 ٤ŤĲž */
+
+	if( sq->dir == SQUARE_DIR_MAX_N ){
+		switch( pre_dir ){
+		case SQUARE_DIR_NORTH:
+			sq->dir = SQUARE_DIR_EAST;
+			break;
+		case SQUARE_DIR_EAST:
+			sq->dir = SQUARE_DIR_SOUTH;
+			break;
+		case SQUARE_DIR_SOUTH:
+			sq->dir = SQUARE_DIR_WEST;
+			break;
+		case SQUARE_DIR_WEST:
+			sq->dir = SQUARE_DIR_NORTH;
+			break;
+		case SQUARE_DIR_MAX_N:
+			sq->dir = SQUARE_DIR_NORTH;
+			break;
+		}
+		if( sq->dir == SQUARE_DIR_MAX_N )
+			sq->dir = SQUARE_DIR_NORTH;
 	}
 
 	sq->x = g_crsr.x;
@@ -2383,7 +2403,7 @@ char	*cb_menu_fight( menu_t **pp, menu_t **dflt )
 char	*cb_menu_load( menu_t **pp, menu_t **dflt )
 {
 	if( menu_load( TRUE ) )
-		reset_all( TRUE );
+		reset_all_save( TRUE );
 
 	return STR_MENU_CANCEL;
 }
@@ -2392,7 +2412,8 @@ char	*cb_menu_load( menu_t **pp, menu_t **dflt )
 
 char	*cb_menu_save( menu_t **pp, menu_t **dflt )
 {
-	menu_save( TRUE );
+	if( menu_save( TRUE ) )
+		reset_all_save( TRUE );
 
 	return STR_MENU_CANCEL;
 }
@@ -2420,7 +2441,7 @@ bool_t	menu_load( bool_t flg_txt )
 	else
 		set_flg_no_save( FALSE );
 
-	print_msg( FLG_NULL, MSG_MENU_LOAD_SUCCESS );
+	print_msg( FLG_NULL, MSG_MENU_LOAD_SUCCESS, n );
 
 	return TRUE;
 }
@@ -2534,7 +2555,8 @@ long	menu_sel_save_load( bool_t flg_save, bool_t flg_txt )
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		flg_exist_data = get_save_load_ttl( ls[k].msg, i, flg_txt );
+		flg_exist_data = get_save_load_ttl( ls[k].msg, i,
+				flg_txt, FALSE );
 		ls[k].call_back = cb_menu_save_load;
 		if( flg_save || flg_exist_data )
 			ls[k].arg = (void *)i;
