@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr.c,v 1.184 2007/02/06 17:30:27 bowkenken Exp $
+* $Id: mnstr.c,v 1.185 2007/05/11 00:42:16 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -2375,8 +2375,9 @@ mnstr_t	*get_mnstr_disperse( mbr_t *mbr )
 	y = mbr->y;
 
 	min_r = MAP_MAX_X + MAP_MAX_Y;
-	ret_p = NULL;
 	n = 0;
+	ret_p = NULL;
+
 	head = &mnstr_used;
 	for( p = head->next->next; p != NULL; p = p->next ){
 		pp = p->prev;
@@ -2414,6 +2415,118 @@ mnstr_t	*get_mnstr_disperse( mbr_t *mbr )
 	return ret_p;
 }
 
+/***************************************************************
+* 1  HP ʤ󥹥򸡺
+* long x : X ɸ
+* long y : Y ɸ
+* return : 󥹥
+***************************************************************/
+
+mnstr_t	*get_mnstr_hp_min( long x, long y )
+{
+	return get_mnstr_hp_mp_min_max( x, y, TRUE, -1 );
+}
+
+/***************************************************************
+* 1  HP ¿󥹥򸡺
+* long x : X ɸ
+* long y : Y ɸ
+* return : 󥹥
+***************************************************************/
+
+mnstr_t	*get_mnstr_hp_max( long x, long y )
+{
+	return get_mnstr_hp_mp_min_max( x, y, TRUE, +1 );
+}
+
+/***************************************************************
+* 1  MP ʤ󥹥򸡺
+* long x : X ɸ
+* long y : Y ɸ
+* return : 󥹥
+***************************************************************/
+
+mnstr_t	*get_mnstr_mp_min( long x, long y )
+{
+	return get_mnstr_hp_mp_min_max( x, y, FALSE, -1 );
+}
+
+/***************************************************************
+* 1  MP ¿󥹥򸡺
+* long x : X ɸ
+* long y : Y ɸ
+* return : 󥹥
+***************************************************************/
+
+mnstr_t	*get_mnstr_mp_max( long x, long y )
+{
+	return get_mnstr_hp_mp_min_max( x, y, FALSE, +1 );
+}
+
+/***************************************************************
+* 1  MP ¿󥹥򸡺
+* long x : X ɸ
+* long y : Y ɸ
+* return : 󥹥
+***************************************************************/
+
+mnstr_t	*get_mnstr_hp_mp_min_max(
+	long x, long y, bool_t flg_hp, long min_max
+)
+{
+	mnstr_t	*head, *p, *pp, *ret_p;
+	long	min_max_n, tmp_n;
+	long	n;
+
+	if( min_max >= +1 )
+		min_max_n = 0;
+	else if( min_max <= -1 )
+		min_max_n = 0x7fffffff;
+	else
+		return NULL;
+	n = 0;
+	ret_p = NULL;
+
+	head = &mnstr_used;
+	for( p = head->next->next; p != NULL; p = p->next ){
+		pp = p->prev;
+		if( pp == head )
+			break;
+
+		if( !chk_flg( pp->flg_map, FLG_MAP_CHR_FIND ) )
+			continue;
+		if( chk_flg_or( pp->stat,
+				FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) ){
+			continue;
+		}
+		if( pp->attitude != ATTITUDE_ENEMY )
+			continue;
+
+		if( flg_hp )
+			tmp_n = pp->abl.hp.n;
+		else
+			tmp_n = pp->abl.mp.n;
+
+		if( (min_max >= +1) && (tmp_n > min_max_n) ){
+			min_max_n = tmp_n;
+			n = 0;
+		} else if( (min_max <= -1) && (tmp_n < min_max_n) ){
+			min_max_n = tmp_n;
+			n = 0;
+		} else if( tmp_n == min_max_n ){
+			n++;
+			if( randm( n ) != 0 )
+				continue;
+		} else {
+			continue;
+		}
+
+		ret_p = pp;
+	}
+
+	return ret_p;
+}
+
 /***************************************************************
 * ȯƤ󥹥˸
 * long x : X ɸ
