@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.c,v 1.186 2007/03/01 23:30:04 bowkenken Exp $
+* $Id: party.c,v 1.190 2007/05/11 00:42:16 bowkenken Exp $
 ***************************************************************/
 
 #define	PARTY_C
@@ -177,8 +177,7 @@ void	init_party( void )
 
 	party.square.x = 1;
 	party.square.y = 1;
-	party.square.dir_x = +1;
-	party.square.dir_y = +-0;
+	party.square.dir = SQUARE_DIR_NORTH;
 	party.square.chr_pos_n[0][0] = 0;
 	party.square.chr_pos_n[0][1] = MBR_NO_POS;
 	party.square.chr_pos_n[0][2] = 1;
@@ -1299,7 +1298,9 @@ void	new_mbr(
 
 	/**/
 
-	init_auto_mark_mbr( mbr->ls_mbr_n );
+	init_spell_new_mbr( mbr->ls_mbr_n );
+
+	init_auto_mark_new_mbr( mbr->ls_mbr_n );
 
 	exp_chr( mbr, DFLT_EXP, TRUE, FALSE, FALSE );
 }
@@ -1326,28 +1327,9 @@ bool_t	reset_mbr_resi( mbr_t *mbr )
 void	set_mbr_dir( void )
 {
 	long	i, j;
-	
-	if( party.square.dir_x < 0 ){
-		party.square.chr_dir[0][0] = party.square.chr_pos_n[0][2];
-		party.square.chr_dir[0][1] = party.square.chr_pos_n[1][2];
-		party.square.chr_dir[0][2] = party.square.chr_pos_n[2][2];
-		party.square.chr_dir[1][0] = party.square.chr_pos_n[0][1];
-		party.square.chr_dir[1][1] = party.square.chr_pos_n[1][1];
-		party.square.chr_dir[1][2] = party.square.chr_pos_n[2][1];
-		party.square.chr_dir[2][0] = party.square.chr_pos_n[0][0];
-		party.square.chr_dir[2][1] = party.square.chr_pos_n[1][0];
-		party.square.chr_dir[2][2] = party.square.chr_pos_n[2][0];
-	} else if( party.square.dir_x > 0 ){
-		party.square.chr_dir[0][0] = party.square.chr_pos_n[2][0];
-		party.square.chr_dir[0][1] = party.square.chr_pos_n[1][0];
-		party.square.chr_dir[0][2] = party.square.chr_pos_n[0][0];
-		party.square.chr_dir[1][0] = party.square.chr_pos_n[2][1];
-		party.square.chr_dir[1][1] = party.square.chr_pos_n[1][1];
-		party.square.chr_dir[1][2] = party.square.chr_pos_n[0][1];
-		party.square.chr_dir[2][0] = party.square.chr_pos_n[2][2];
-		party.square.chr_dir[2][1] = party.square.chr_pos_n[1][2];
-		party.square.chr_dir[2][2] = party.square.chr_pos_n[0][2];
-	} else if( party.square.dir_y < 0 ){
+
+	switch( party.square.dir ){
+	case SQUARE_DIR_NORTH:
 		party.square.chr_dir[0][0] = party.square.chr_pos_n[0][0];
 		party.square.chr_dir[0][1] = party.square.chr_pos_n[0][1];
 		party.square.chr_dir[0][2] = party.square.chr_pos_n[0][2];
@@ -1357,7 +1339,19 @@ void	set_mbr_dir( void )
 		party.square.chr_dir[2][0] = party.square.chr_pos_n[2][0];
 		party.square.chr_dir[2][1] = party.square.chr_pos_n[2][1];
 		party.square.chr_dir[2][2] = party.square.chr_pos_n[2][2];
-	} else if( party.square.dir_y > 0 ){
+		break;
+	case SQUARE_DIR_EAST:
+		party.square.chr_dir[0][0] = party.square.chr_pos_n[2][0];
+		party.square.chr_dir[0][1] = party.square.chr_pos_n[1][0];
+		party.square.chr_dir[0][2] = party.square.chr_pos_n[0][0];
+		party.square.chr_dir[1][0] = party.square.chr_pos_n[2][1];
+		party.square.chr_dir[1][1] = party.square.chr_pos_n[1][1];
+		party.square.chr_dir[1][2] = party.square.chr_pos_n[0][1];
+		party.square.chr_dir[2][0] = party.square.chr_pos_n[2][2];
+		party.square.chr_dir[2][1] = party.square.chr_pos_n[1][2];
+		party.square.chr_dir[2][2] = party.square.chr_pos_n[0][2];
+		break;
+	case SQUARE_DIR_SOUTH:
 		party.square.chr_dir[0][0] = party.square.chr_pos_n[2][2];
 		party.square.chr_dir[0][1] = party.square.chr_pos_n[2][1];
 		party.square.chr_dir[0][2] = party.square.chr_pos_n[2][0];
@@ -1367,7 +1361,22 @@ void	set_mbr_dir( void )
 		party.square.chr_dir[2][0] = party.square.chr_pos_n[0][2];
 		party.square.chr_dir[2][1] = party.square.chr_pos_n[0][1];
 		party.square.chr_dir[2][2] = party.square.chr_pos_n[0][0];
+		break;
+	case SQUARE_DIR_WEST:
+		party.square.chr_dir[0][0] = party.square.chr_pos_n[0][2];
+		party.square.chr_dir[0][1] = party.square.chr_pos_n[1][2];
+		party.square.chr_dir[0][2] = party.square.chr_pos_n[2][2];
+		party.square.chr_dir[1][0] = party.square.chr_pos_n[0][1];
+		party.square.chr_dir[1][1] = party.square.chr_pos_n[1][1];
+		party.square.chr_dir[1][2] = party.square.chr_pos_n[2][1];
+		party.square.chr_dir[2][0] = party.square.chr_pos_n[0][0];
+		party.square.chr_dir[2][1] = party.square.chr_pos_n[1][0];
+		party.square.chr_dir[2][2] = party.square.chr_pos_n[2][0];
+		break;
+	case SQUARE_DIR_MAX_N:
+		break;
 	}
+
 	for( i = 0; i < SQUARE_HEIGHT; i++ ){
 		for( j = 0; j < SQUARE_WIDTH; j++ ){
 			long	n;
@@ -1527,7 +1536,7 @@ void	move_all_mbr_trgt( void )
 
 /**/
 
-void	move_phase_party( void )
+void	move_phase_all_mbr( void )
 {
 	long	i;
 
@@ -1537,7 +1546,7 @@ void	move_phase_party( void )
 
 /**/
 
-void	act_phase_party( void )
+void	act_phase_all_mbr( void )
 {
 	long	i;
 
@@ -1545,7 +1554,12 @@ void	act_phase_party( void )
 		act_phase_chr( party.mbr[i] );
 		set_modifier( party.mbr[i] );
 	}
+}
 
+/**/
+
+void	act_phase_party( void )
+{
 	switch( party.act.kind ){
 	default:
 		break;
@@ -2227,6 +2241,10 @@ void	remove_mbr( mbr_t *mbr )
 
 	ls_mbr[i]->mbr_n = MBR_N_NOT_JOIN;
 	ls_mbr[i]->stat |= FLG_STAT_NOT_EXIST;
+
+	/* ʸ */
+
+	remove_cast_tab( ls_mbr[i]->ls_mbr_n );
 }
 
 /**/
@@ -2242,8 +2260,9 @@ mbr_t	*get_mbr_nearest( long x, long y )
 	dun = get_dun();
 
 	min_r = MAP_MAX_X + MAP_MAX_Y;
-	ret_p = NULL;
 	n = 0;
+	ret_p = NULL;
+
 	for( i = 0; i < MBR_MAX_N; i++ ){
 		pos_t	pos1, pos2;
 
@@ -2293,8 +2312,9 @@ mbr_t	*get_mbr_near( long x, long y )
 	dun = get_dun();
 
 	min_r = MAP_MAX_X + MAP_MAX_Y;
-	ret_p = NULL;
 	n = 0;
+	ret_p = NULL;
+
 	for( i = 0; i < MBR_MAX_N; i++ ){
 		pos_t	pos1, pos2;
 
@@ -2351,8 +2371,9 @@ mbr_t	*get_mbr_disperse( mbr_t *mbr )
 	dun = get_dun();
 
 	min_r = MAP_MAX_X + MAP_MAX_Y;
-	ret_p = NULL;
 	n = 0;
+	ret_p = NULL;
+
 	for( i = 0; i < MBR_MAX_N; i++ ){
 		pos_t	pos1, pos2;
 
@@ -2404,8 +2425,9 @@ mbr_t	*get_mbr_randm( long x, long y )
 
 	dun = get_dun();
 
-	ret_p = NULL;
 	n = 0;
+	ret_p = NULL;
+
 	for( i = 0; i < MBR_MAX_N; i++ ){
 		pos_t	pos1, pos2;
 
@@ -2457,8 +2479,9 @@ mbr_t	*get_mbr_stagger( mbr_t *mbr )
 	dun = get_dun();
 
 	min_r = MAP_MAX_X + MAP_MAX_Y;
-	ret_p = NULL;
 	n = 0;
+	ret_p = NULL;
+
 	for( i = 0; i < MBR_MAX_N; i++ ){
 		pos_t	pos1, pos2;
 
@@ -2504,6 +2527,115 @@ mbr_t	*get_mbr_stagger( mbr_t *mbr )
 
 /**/
 
+mbr_t	*get_mbr_hp_min( void )
+{
+	return get_mbr_hp_mp_min_max( TRUE, -1 );
+}
+
+/**/
+
+mbr_t	*get_mbr_hp_max( void )
+{
+	return get_mbr_hp_mp_min_max( TRUE, +1 );
+}
+
+/**/
+
+mbr_t	*get_mbr_mp_min( void )
+{
+	return get_mbr_hp_mp_min_max( FALSE, -1 );
+}
+
+/**/
+
+mbr_t	*get_mbr_mp_max( void )
+{
+	return get_mbr_hp_mp_min_max( FALSE, +1 );
+}
+
+/**/
+
+mbr_t	*get_mbr_hp_mp_min_max( bool_t flg_hp, long min_max )
+{
+	mbr_t	*p, *ret_p;
+	rate_t	min_max_rate, tmp_rate;
+	long	min_max_n, tmp_n;
+	long	n;
+	dun_t	*dun;
+	long	i;
+
+	dun = get_dun();
+
+	if( min_max >= +1 ){
+		min_max_rate = (rate_t)0;
+		min_max_n = 0;
+	} else if( min_max <= -1 ){
+		min_max_rate = _100_PERCENT;
+		min_max_n = 0x7fffffff;
+	} else {
+		return NULL;
+	}
+	n = 0;
+	ret_p = NULL;
+
+	for( i = 0; i < MBR_MAX_N; i++ ){
+		p = party.mbr[i];
+
+		if( chk_flg_or( p->stat,
+				FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) ){
+			continue;
+		}
+
+		if( flg_hp ){
+			tmp_rate = p->abl.hp.n * _100_PERCENT
+					/ p->abl.hp.max;
+			tmp_n = p->abl.hp.n;
+		} else {
+			tmp_rate = p->abl.mp.n * _100_PERCENT
+					/ p->abl.mp.max;
+			tmp_n = p->abl.mp.n;
+		}
+
+		if( (min_max >= +1) && (tmp_rate > min_max_rate) ){
+			min_max_rate = tmp_rate;
+			min_max_n = tmp_n;
+			n = 1;
+		} else if( (min_max <= -1) && (tmp_rate < min_max_rate) ){
+			min_max_rate = tmp_rate;
+			min_max_n = tmp_n;
+			n = 1;
+		} else if( tmp_rate == min_max_rate ){
+			if( (min_max >= +1) && (tmp_n > min_max_n) ){
+				min_max_rate = tmp_rate;
+				min_max_n = tmp_n;
+				n = 1;
+			} else if( (min_max <= -1) && (tmp_n < min_max_n) ){
+				min_max_rate = tmp_rate;
+				min_max_n = tmp_n;
+				n = 1;
+			} else if( tmp_n == min_max_n ){
+				n++;
+				if( randm( n ) == 0 ){
+					min_max_rate = tmp_rate;
+					min_max_n = tmp_n;
+				} else {
+					continue;
+				}
+			} else {
+				continue;
+			}
+		} else {
+			continue;
+		}
+
+		ret_p = p;
+	}
+
+	return ret_p;
+}
+
+/**/
+
 bool_t	chk_already_mark( void *p, mbr_t *mbr )
 {
 	party_t	*pty;
