@@ -13,7 +13,7 @@ bool_t	reset_pet_resi( pet_t *pet );
 void	clr_map_all_pet( void );
 void	set_map_all_pet( void );
 void	appear_all_pet( void );
-void	appear_pet( pet_t *pet );
+void	appear_pet( pet_t *p );
 void	move_phase_all_pet( void );
 void	act_phase_all_pet( void );
 void	set_act_pet_std( pet_t *p );
@@ -24,14 +24,14 @@ pet_t	**get_ls_pet( void );
 pet_t	*get_pet( long x, long y );
 pet_t	*get_npc_request( request_t *req );
 void	clr_pet_owner( pet_t *p );
-bool_t	chk_can_join_pet( pet_t *pet );
-bool_t	chk_can_not_join_pet( pet_t *pet );
-bool_t	join_pet( pet_t *pet );
-bool_t	not_join_pet( pet_t *pet );
-void	die_pet( pet_t *pet );
-void	remove_pet( pet_t *pet );
-bool_t	dismissal( pet_t *pet );
-bool_t	is_pet( pet_t *pet );
+bool_t	chk_can_join_pet( pet_t *p );
+bool_t	chk_can_not_join_pet( pet_t *p );
+bool_t	join_pet( pet_t *p );
+bool_t	not_join_pet( pet_t *p );
+void	die_pet( pet_t *p );
+void	remove_pet( pet_t *p );
+bool_t	dismissal( pet_t *p );
+bool_t	is_pet( pet_t *p );
 
 #ifdef __cplusplus
 }
