@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell.c,v 1.158 2007/03/18 05:45:53 bowkenken Exp $
+* $Id: spell.c,v 1.162 2007/03/27 23:34:26 bowkenken Exp $
 ***************************************************************/
 
 #define	SPELL_C
@@ -37,8 +37,8 @@
 
 /**/
 
-#define	CHK_SPELL_LEV_RATE	((rate_t)80)
-#define	CHK_SPELL_LEV_RATE_BASE	((rate_t)80)
+#define	CHK_SPELL_LEV_RATE	((rate_t)200)
+#define	CHK_SPELL_LEV_RATE_BASE	((rate_t)90)
 
 #define	SPELL_PRICE_LEV_MUL	((rate_t)500)
 
@@ -94,12 +94,8 @@ void	init_spell( void )
 	menu_t	*ls;
 	long	i;
 
-	for( m = 0; m < LS_MBR_MAX_N; m++ ){
-		for( k = 0; k < SPELL_KIND_MAX_N; k++ ){
-			cast_tab[m][k].kind = (spell_kind_t)k;
-			cast_tab[m][k].flg_cast = FALSE;
-		}
-	}
+	for( m = 0; m < LS_MBR_MAX_N; m++ )
+		init_spell_new_mbr( m );
 
 	for( k = SPELL_KIND_NULL + 1; k < SPELL_KIND_MAX_N; k++ ){
 		if( spell_tab[k].kind == SPELL_KIND_NULL )
@@ -137,11 +133,6 @@ void	init_spell( void )
 				MSG( ls[i].n_msg ),
 				tab->mp, tab->hp, tab->gold );
 	}
-
-	if( g_flg_debug )
-		init_spell_debug();
-	else
-		init_spell_dflt();
 }
 
 /**/
@@ -198,6 +189,18 @@ void	init_spell_debug( void )
 
 /**/
 
+void	init_spell_new_mbr( long ls_mbr_n )
+{
+	long	k;
+
+	for( k = 0; k < SPELL_KIND_MAX_N; k++ ){
+		cast_tab[ls_mbr_n][k].kind = (spell_kind_t)k;
+		cast_tab[ls_mbr_n][k].flg_cast = FALSE;
+	}
+}
+
+/**/
+
 void	init_spell_dflt( void )
 {
 	long	m;
@@ -1477,7 +1480,7 @@ void	chr_cast_spell_sub(
 
 	if( flg_chr && !chk_spell( chr, tab, flg_item ) ){
 		curs_attrset_chr( chr, -1, FALSE );
-		print_msg( FLG_NULL, MSG_FAIL_SPELL,
+		print_msg_find( chr, FLG_NULL, MSG_FAIL_SPELL,
 				chr->name, tab->name );
 		curs_attrset_dflt();
 
@@ -1489,7 +1492,7 @@ void	chr_cast_spell_sub(
 	if( flg_chr && (tab->resi != RESI_KIND_MAX_N)
 			&& resi_roll( chr, tab->abl, d_p, tab->resi ) ){
 		curs_attrset_chr( d_p, +1, FALSE );
-		print_msg( FLG_NULL, MSG_RESI_SPELL,
+		print_msg_find( d_p, FLG_NULL, MSG_RESI_SPELL,
 				d_p->name, tab->name );
 		curs_attrset_dflt();
 
@@ -1503,7 +1506,7 @@ void	chr_cast_spell_sub(
 
 	if( flg_chr && chk_flg( d_p->stat, FLG_STAT_IRON_BODY ) ){
 		curs_attrset_chr( d_p, +1, FALSE );
-		print_msg( FLG_NULL, MSG_REPEL_SPELL,
+		print_msg_find( d_p, FLG_NULL, MSG_REPEL_SPELL,
 				d_p->name, tab->name );
 		curs_attrset_dflt();
 
@@ -2601,16 +2604,20 @@ bool_t	set_chr_learned_spell( chr_t *chr, spell_kind_t kind, bool_t flg )
 		return FALSE;
 	tab->flg_cast = flg;
 
-	if( flg ){
-		curs_attrset_chr( chr, +1, TRUE );
-		print_msg( FLG_NULL, MSG_LEARN_SPELL,
-				chr->name, get_spell_name( kind ) );
-		curs_attrset_dflt();
-	} else {
-		curs_attrset_chr( chr, -1, TRUE );
-		print_msg( FLG_NULL, MSG_FORGET_SPELL,
-				chr->name, get_spell_name( kind ) );
-		curs_attrset_dflt();
+	if( g_flg_init ){
+		if( flg ){
+			curs_attrset_chr( chr, +1, TRUE );
+			print_msg( FLG_NULL, MSG_LEARN_SPELL,
+					chr->name,
+					get_spell_name( kind ) );
+			curs_attrset_dflt();
+		} else {
+			curs_attrset_chr( chr, -1, TRUE );
+			print_msg( FLG_NULL, MSG_FORGET_SPELL,
+					chr->name,
+					get_spell_name( kind ) );
+			curs_attrset_dflt();
+		}
 	}
 
 	return tab->flg_cast;
@@ -2674,7 +2681,8 @@ void	learn_spell_sha( chr_t *chr )
 			continue;
 
 		if( lev >= spell_tab->lev ){
-			set_chr_learned_spell( chr, (spell_kind_t)k, TRUE );
+			set_chr_learned_spell( chr,
+					(spell_kind_t)k, TRUE );
 		}
 	}
 }
@@ -2897,6 +2905,60 @@ bool_t	chk_learn_spell_item( chr_t *chr, spell_kind_t kind )
 
 /**/
 
+void	arrange_cast_tab( long trgt_ls_mbr_n, long d )
+{
+	mbr_t	**ls_mbr;
+	cast_tab_t	tmp_cast_tab[SPELL_KIND_MAX_N];
+	long	i;
+
+	ls_mbr = get_ls_mbr();
+	copy_cast_tab( tmp_cast_tab, cast_tab[trgt_ls_mbr_n] );
+
+	if( d <= -1 ){
+		for( i = trgt_ls_mbr_n - 1; i >= 0; i-- )
+			copy_cast_tab( cast_tab[i + 1], cast_tab[i] );
+
+		copy_cast_tab( cast_tab[0], tmp_cast_tab );
+	} else {
+		for( i = trgt_ls_mbr_n + 1; i < LS_MBR_MAX_N; i++ ){
+			if( chk_flg( ls_mbr[i]->stat,
+					FLG_STAT_NOT_EXIST ) ){
+				break;
+			}
+
+			copy_cast_tab( cast_tab[i - 1], cast_tab[i] );
+		}
+
+		copy_cast_tab( cast_tab[i - 1], tmp_cast_tab );
+	}
+}
+
+/**/
+
+void	remove_cast_tab( long trgt_ls_mbr_n )
+{
+	arrange_cast_tab( trgt_ls_mbr_n, +1 );
+}
+
+/**/
+
+bool_t	copy_cast_tab( cast_tab_t dst[], cast_tab_t src[] )
+{
+	spell_kind_t	k;
+
+	if( dst == NULL )
+		return FALSE;
+	if( src == NULL )
+		return FALSE;
+
+	for( k = SPELL_KIND_NULL + 1; k < SPELL_KIND_MAX_N; k++ )
+		dst[k] = src[k];
+
+	return TRUE;
+}
+
+/**/
+
 char	*get_spell_vfx_str( spell_kind_t spell_kind )
 {
 	switch( spell_kind ){
