@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu.c,v 1.106 2007/02/02 14:09:32 bowkenken Exp $
+* $Id: tmenu.c,v 1.111 2007/05/12 09:20:47 bowkenken Exp $
 ***************************************************************/
 
 #define	TMENU_C
@@ -865,7 +865,8 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 		if( g_deal_kind != DEAL_KIND_SALE_EQUIP ){
 			str_nz_cpy( ls[*k].path, "/shop/sale equip",
 					MENU_PATH_MAX_LEN );
-			str_nz_cpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
+			str_nz_cpy( ls[*k].kind, "<Item>",
+					MENU_KIND_MAX_LEN );
 			ls[*k].accel_key = 'X';
 			ls[*k].short_key[0] = '\0';
 			str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_SALE_EQUIP,
@@ -880,7 +881,8 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 		if( g_deal_kind != DEAL_KIND_SALE_ITEM ){
 			str_nz_cpy( ls[*k].path, "/shop/sale item",
 					MENU_PATH_MAX_LEN );
-			str_nz_cpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
+			str_nz_cpy( ls[*k].kind, "<Item>",
+					MENU_KIND_MAX_LEN );
 			ls[*k].accel_key = 'Y';
 			ls[*k].short_key[0] = '\0';
 			str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_SALE_ITEM,
@@ -893,8 +895,10 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 
 		/* Buy */
 		if( g_deal_kind != DEAL_KIND_BUY ){
-			str_nz_cpy( ls[*k].path, "/shop/buy", MENU_PATH_MAX_LEN );
-			str_nz_cpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
+			str_nz_cpy( ls[*k].path, "/shop/buy",
+					MENU_PATH_MAX_LEN );
+			str_nz_cpy( ls[*k].kind, "<Item>",
+					MENU_KIND_MAX_LEN );
 			ls[*k].accel_key = 'Z';
 			ls[*k].short_key[0] = '\0';
 			str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_BUY,
@@ -1185,6 +1189,8 @@ long	menu_shop_sale(
 
 	lost_trgt( item );
 
+	asgn = NULL;
+
 	switch( shop_n ){
 	default:
 	case SHOP_N_INN:
@@ -2036,6 +2042,8 @@ char	*cb_menu_bar_arrange( long d )
 		g_sel_ls_mbr = ls_mbr[i - 1];
 	}
 
+	arrange_cast_tab( trgt_ls_mbr_n, d );
+
 	return "/bar/form/edit member/edit member";
 }
 
@@ -2624,7 +2632,16 @@ char	*cb_menu_bar_load( menu_t **pp, menu_t **dflt )
 {
 	menu_bar_load();
 
-	return STR_MENU_CANCEL;
+	return NULL;
+}
+
+/**/
+
+char	*cb_menu_bar_save( menu_t **pp, menu_t **dflt )
+{
+	menu_bar_save();
+
+	return NULL;
 }
 
 /**/
@@ -2632,16 +2649,15 @@ char	*cb_menu_bar_load( menu_t **pp, menu_t **dflt )
 void	menu_bar_load( void )
 {
 	if( menu_load( FALSE ) )
-		reset_all( TRUE );
+		reset_all_save( TRUE );
 }
 
 /**/
 
-char	*cb_menu_bar_save( menu_t **pp, menu_t **dflt )
+void	menu_bar_save( void )
 {
-	menu_save( FALSE );
-
-	return STR_MENU_CANCEL;
+	if( menu_save( FALSE ) )
+		reset_all_save( TRUE );
 }
 
 /**/
