@@ -30,6 +30,7 @@ bool_t	navi_party_stairs();
 bool_t	open_door_shop( long n );
 bool_t	enter_shop( void );
 void	party_exit_shop( long dr_n );
+void	party_exit_bar( void );
 bool_t	chk_shop_open( shop_n_t shop_n, bool_t flg_print );
 bool_t	chk_package_item( item_t *item );
 void	stay_inn( bool_t flg_short_stay );
@@ -57,7 +58,7 @@ void	chk_morning_glow( long turn );
 void	chk_evening_glow( long turn );
 long	get_glow_n( long turn, bool_t flg_morning );
 void	set_map_glow( long dx, long dy, bool_t flg_morning );
-void	hear_rumor( void );
+void	hear_rumor( shop_n_t shop_n );
 bool_t	chk_discount( void );
 bool_t	chk_discount_day( void );
 bool_t	chk_discount_turn();
