@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: town.c,v 1.124 2007/02/28 21:40:49 bowkenken Exp $
+* $Id: town.c,v 1.125 2007/05/05 21:16:08 bowkenken Exp $
 ***************************************************************/
 
 #define	TOWN_C
@@ -1435,7 +1435,26 @@ void	party_exit_shop( long dr_n )
 
 	move_crsr_abs( pty->square.x, pty->square.y );
 
-	add_turn( SHOP_ADD_TURN_N );
+	if( dun->door[dr_n].mnr != FACE_MNR_SHOP_BAR )
+		add_turn( SHOP_ADD_TURN_N );
+}
+
+/**/
+
+void	party_exit_bar( void )
+{
+	door_t	*dr;
+
+	dr = get_shop_door( SHOP_N_BAR );
+	if( dr != NULL ){
+#if	1
+//@@@
+		party_exit_shop( dr->n );
+#else
+		open_door_shop( dr->n );
+		exec_all_phase();
+#endif
+	}
 }
 
 /**/
