@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: trap.h,v 1.32 2007/01/11 17:31:35 bowkenken Exp $
+* $Id: trap.h,v 1.33 2007/03/19 09:11:43 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	TRAP_H
@@ -58,7 +58,7 @@
 # endif
 #endif
 
-#if	(!defined( NDEBUG )) && defined( DEBUG ) && defined( D_TEST_TRAP )
+#ifdef	D_TEST_TRAP
 # define	TRAP_AVE_N	512
 # define	TRAP_MAX_N	1024
 #else
